@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20240930';
+our $VERSION = '0.20241031';
 
-# Table last modified: 2024-09-30
+# Table last modified: 2024-10-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -88,7 +88,7 @@ our %ZIP_TABLE = (
     '082' => '(?:865[01])',
     '083' => '(?:8(?:585|650))',
     '084' => '(?:8(?:5(?:[01]1|55|67)|6(?:70|86)))',
-    '085' => '(?:(?:8(?:5(?:67|1[0-25]|3[35]|2[27]|5[01578]|8[01568]|0[125])|6(?:[34]9|77|5[05]|6[08]))|029[23]))',
+    '085' => '(?:(?:8(?:5(?:67|1[0-25]|3[35]|2[27]|5[01578]|8[01568]|0[125])|6(?:[34]9|60|77|5[05]))|029[23]))',
     '086' => '(?:1(?:89[23]|197))',
     '087' => '(?:(?:8(?:5(?:55|88)|6(?:09|86)|711)|0192))',
     '088' => '(?:(?:0(?:39[2-5]|59[258]|19[23]|692)|1(?:19[235]|592)|3(?:29[23]|395)|259[23]))',
@@ -103,15 +103,15 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6|78)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|3[09]|0[235]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|6[0-57-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|3[09]|0[235]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[57]|2[1246-9]|3[01367]|7[026]|4[235-8]|1[01679])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:5[013589]|8[38]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
-    '103' => '(?:8(?:4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|2(?:5[0-2569]|3\d|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|2[0-25]|0[1-356]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
+    '103' => '(?:8(?:2(?:5[0-2569]|3[0-689]|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|2[0-25]|0[1-356]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
     '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[05-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|3[14]|1[0-26-9]|8[24]|4[08]|6[038])|5(?:32|81|0[23578]|7[02]|1[146]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
-    '108' => '(?:(?:8(?:5(?:2[0-35]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|4[035]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|7[056]|4[0-38]|1[0-267]|0[1-36-9]|3[0-4]|5[05]|2[0245])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|71|[01][15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
+    '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|1[126-9]|3[14]|8[24]|4[08]|6[038])|5(?:32|81|0[23578]|7[02]|1[146]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:20|4[0289]|7[013]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
+    '108' => '(?:(?:8(?:5(?:2[0-35]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|4[035]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|7[056]|4[0-38]|1[0-267]|0[1-36-9]|3[0-4]|5[05]|2[0245])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|2[28]|1[125-7]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|71|[01][15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:6(?:3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
@@ -134,7 +134,7 @@ our %ZIP_TABLE = (
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[018]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|0[23679]|8[0346]|6[0367]|2[1-3569]|5[1248]|1[1256])|6(?:4[04]|3[0147]|2[1568]|6[013689]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|(?:45|81)0))',
-    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:8[78]|1[1-368]|2[0-6])|2(?:55|60|1[04]|0[1-6])|7(?:1[056]|0[17])|001|924))',
+    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|2(?:55|60|1[04]|0[1-6])|4(?:8[78]|1[168]|2[01356])|7(?:1[056]|0[17])|001|924))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|22|66)|777))',
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
     '144' => '(?:8(?:5(?:44|66|5[015]|8[018]|7[057]|2[25]|3[1-356]|1[01356]|0[56])|6(?:02|11|5[056]|7[78]|2[1-36]|6[016])))',
@@ -152,7 +152,7 @@ our %ZIP_TABLE = (
     '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|1[1369]|[24][17]|6[168]|5[1-38]|0[1469])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|0[1479]|4[37]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[058]|7[1368]|8[048]|0[27]|2[12]|1[125])|5(?:75|[16][25]|0[235]|3[05]|8[57]|5[16-8]|4[034])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
-    '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|6[18])|4(?:56|7[18])|9(?:43|3[68])|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|80|2[06]|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
+    '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|6[18])|4(?:56|7[18])|9(?:43|3[68])|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:[28]0|02|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
     '164' => '(?:8(?:5(?:[37]0|55|4[015]|2[25]|6[67]|8[58]|0[1-5])|6(?:[25]0|[68]6|7[78]|1[167]|4[24]|[03][18])|7(?:25|0[15])))',
     '165' => '(?:8(?:(?:63|78)0|555))',
     '166' => '(?:85(?:20|88|0[1-3]|6[5-7]|4[025]|3[1-357-9]|7[078]))',
@@ -288,7 +288,7 @@ our %ZIP_TABLE = (
     '312' => '(?:85(?:0[1-578]|1[01]))',
     '313' => '(?:8(?:6(?:[68]6|11)|511))',
     '314' => '(?:(?:8(?:501|655)|019[2-578]))',
-    '315' => '(?:(?:8(?:5(?:85|2[2357]|1[1-368])|640)|0195))',
+    '315' => '(?:(?:8(?:5(?:85|2[2357]|1[1-468])|640)|0195))',
     '316' => '(?:85(?:11|33|0[12]))',
     '317' => '(?:8(?:5(?:[58]5|11)|60[12]))',
     '318' => '(?:85(?:11|0[15]))',
@@ -418,7 +418,7 @@ our %ZIP_TABLE = (
     '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|2[025]|1[0-25-7]|4[0235]|8[01568]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[238]|89[23])))',
     '445' => '(?:8(?:5(?:[58]5|1[01]|0[1-35])|60[12]))',
     '446' => '(?:8(?:5(?:40|2[0-356]|1[124578]|5[058]|3[35]|0[1-8]|8[58])|6(?:35|41|86|0[12])))',
-    '447' => '(?:8(?:5(?:0[1-35-8]|1[0-2])|6(?:[18]0|0[1358])))',
+    '447' => '(?:8(?:5(?:1[0-2]|0[1-3578])|6(?:[18]0|0[1358])))',
     '448' => '(?:8(?:6(?:10|22|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:11|50|0[156]|2[35]|3[13-5]|4[023])|731))',
     '449' => '(?:029[23])',
     '450' => '(?:(?:8(?:5(?:40|85|0[135]|[23][03]|6[17]|7[57]|1[15])|6(?:[248]0|[05]1|1[1458])|7(?:11|65)|99[35-7])|6(?:(?:13|36)3|660)))',
@@ -660,7 +660,7 @@ our %ZIP_TABLE = (
     '697' => '(?:(?:8(?:5(?:01|85|1[12])|686|789)|0492))',
     '698' => '(?:(?:8(?:50[13-6]|65[01])|0292))',
     '699' => '(?:(?:0(?:5(?:88|9[23])|19[23]|29[23]|49[26]|69[67]|792)|1(?:39[2-6]|29[23]|592|898)|4(?:29[28]|692)|5(?:292|695)|2598))',
-    '700' => '(?:8(?:5(?:2[0-2568]|4[04-69]|7[0-2578]|8[014-69]|0[1-8]|3[0-589]|5[0-24-8]|6[0-27-9]|1[0-24-9])|6(?:6[06]|7[78]|2[01358]|1[014-8]|5[057]|8[016-9]|0[1-8]|4[05]|3[459])|7(?:18|61|94|0[17]|2[27]|3[1-48])))',
+    '700' => '(?:8(?:5(?:2[0-2568]|4[04-69]|7[0-2578]|8[014-69]|0[1-8]|3[0-589]|5[0-24-8]|6[0-27-9]|1[0-24-9])|6(?:77|6[06]|2[01358]|1[014-8]|5[057]|8[016-9]|0[1-8]|4[05]|3[459])|7(?:18|61|94|0[17]|2[27]|3[1-48])))',
     '701' => '(?:(?:0(?:29[25-8]|19[2357]|39[38])|4(?:39[248]|29[23]|59[23])|1(?:19[25]|29[26])|2(?:292|595)|329[23]))',
     '702' => '(?:8(?:5(?:44|0[1-35-8]|1[0-25])|60[1-35-79]))',
     '703' => '(?:8(?:5(?:20|44|6[06]|3[03]|8[0568]|0[1258]|5[058]|7[03-5]|1[016])|6(?:55|86)|750))',
@@ -910,7 +910,7 @@ our %ZIP_TABLE = (
     '951' => '(?:8(?:5(?:70|4[04]|2[018]|1[0-489]|6[067]|8[0156]|0[2-478]|3[1356]|5[0-6])|6(?:01|40|78|8[056]|2[0259]|5[05]|3[023]|1[0-2]|6[68])))',
     '952' => '(?:(?:1(?:59[23]|292|393)|850[12]))',
     '953' => '(?:(?:8(?:6(?:66|0[12])|50[13])|019[23]))',
-    '954' => '(?:(?:86(?:19|58|86)|019[25]))',
+    '954' => '(?:(?:86(?:19|58|86)|019[235]))',
     '955' => '(?:(?:8(?:5(?:43|67|0[135]|5[058]|7[57]|8[589]|1[01])|6(?:12|55|66|77|0[1-3]|8[68]))|0192))',
     '956' => '(?:(?:86(?:[23]5|0[1-3])|0192))',
     '957' => '(?:(?:8(?:5(?:[34]0|11|22|67|5[058]|8[58]|0[236])|6(?:[68]6|01)|701)|0(?:19[235-7]|293)))',
